@@ -91,7 +91,7 @@ class PubSubCommandsMixin:
 
     @command(name='PUBSUB HELP', fixed=())
     def pubsub_help(self, *args):
-        if self.version >= 7:
+        if self.version >= (7,):
             help_strings = [
                 'PUBSUB <subcommand> [<arg> [value] [opt] ...]. Subcommands are:',
                 'CHANNELS [<pattern>]',
@@ -109,7 +109,7 @@ class PubSubCommandsMixin:
                 '    Return the number of subscribers for the specified shard level channel(s'
                 ')',
                 'HELP',
-                '    Prints this help.'
+                ('    Prints this help.' if self.version < (7, 1) else '    Print this help.'),
             ]
         else:
             help_strings = [
