@@ -3,7 +3,9 @@ from __future__ import annotations
 import functools
 import itertools
 import math
-from typing import Union, Optional
+import random
+import sys
+from typing import Union, Optional, List
 
 from fakeredis import _msgs as msgs
 from fakeredis._command_args_parsing import extract_args
@@ -11,6 +13,15 @@ from fakeredis._commands import (command, Key, Int, Float, CommandItem, Timeout,
 from fakeredis._helpers import (SimpleError, casematch, null_terminate, )
 from fakeredis._zset import ZSet
 
+SORTED_SET_METHODS = {
+    'ZUNIONSTORE': lambda s1, s2: s1 | s2,
+    'ZUNION': lambda s1, s2: s1 | s2,
+    'ZINTERSTORE': lambda s1, s2: s1.intersection(s2),
+    'ZINTER': lambda s1, s2: s1.intersection(s2),
+    'ZDIFFSTORE': lambda s1, s2: s1 - s2,
+    'ZDIFF': lambda s1, s2: s1 - s2,
+}
+
 
 class SortedSetCommandsMixin:
     # Sorted set commands
@@ -67,7 +78,7 @@ class SortedSetCommandsMixin:
             out.append(item)
         return out
 
-    def _apply_withscores(self, items, withscores):
+    def _apply_withscores(self, items, withscores: bool) -> List[bytes]:
         if withscores:
             out = []
             for item in items:
@@ -95,7 +106,8 @@ class SortedSetCommandsMixin:
             raise SimpleError(msgs.ZADD_INCR_LEN_ERROR_MSG)
         # Parse all scores first, before updating
         items = [
-            (0.0 + Float.decode(elements[j]) if self.version >= 7 else Float.decode(elements[j]), elements[j + 1])
+            ((0.0 + Float.decode(elements[j]) if self.version >= (7,)
+              else Float.decode(elements[j]), elements[j + 1]))
             for j in range(0, len(elements), 2)
         ]
         old_len = len(zset)
@@ -156,14 +168,16 @@ class SortedSetCommandsMixin:
     def zlexcount(self, key, _min, _max):
         return key.value.zlexcount(_min.value, _min.exclusive, _max.value, _max.exclusive)
 
-    def _zrangebyscore(self, key, _min, _max, reverse, withscores, offset, count):
+    def _zrangebyscore(self, key, _min, _max, reverse, withscores, offset, count) -> List[bytes]:
         zset = key.value
+        if reverse:
+            _min, _max = _max, _min
         items = list(zset.irange_score(_min.lower_bound, _max.upper_bound, reverse=reverse))
         items = self._limit_items(items, offset, count)
         items = self._apply_withscores(items, withscores)
         return items
 
-    def _zrange(self, key, start, stop, reverse, withscores, byscore):
+    def _zrange(self, key, start, stop, reverse, withscores, byscore) -> List[bytes]:
         zset = key.value
         if byscore:
             items = zset.irange_score(start.lower_bound, stop.upper_bound, reverse=reverse)
@@ -176,7 +190,7 @@ class SortedSetCommandsMixin:
         items = self._apply_withscores(items, withscores)
         return items
 
-    def _zrangebylex(self, key, _min, _max, reverse, offset, count):
+    def _zrangebylex(self, key, _min, _max, reverse, offset, count) -> List[bytes]:
         zset = key.value
         if reverse:
             _min, _max = _max, _min
@@ -212,6 +226,15 @@ class SortedSetCommandsMixin:
     def zrange(self, key, start, stop, *args):
         return self._zrange_args(key, start, stop, *args)
 
+    @command((Key(ZSet), Key(ZSet), bytes, bytes), (bytes,))
+    def zrangestore(self, dest: CommandItem, src, start, stop, *args):
+        results_list = self._zrange_args(src, start, stop, *args)
+        res = ZSet()
+        for item in results_list:
+            res.add(item, src.value.get(item))
+        dest.update(res)
+        return len(res)
+
     @command((Key(ZSet), ScoreTest, ScoreTest), (bytes,))
     def zrevrange(self, key, start, stop, *args):
         (withscores, byscore), _ = extract_args(args, ('withscores', 'byscore'))
@@ -239,7 +262,7 @@ class SortedSetCommandsMixin:
         return self._zrangebyscore(key, _min, _max, False, withscores, offset, count)
 
     @command((Key(ZSet), ScoreTest, ScoreTest), (bytes,))
-    def zrevrangebyscore(self, key, _max, _min, *args):
+    def zrevrangebyscore(self, key, _min, _max, *args):
         (withscores, (offset, count)), _ = extract_args(args, ('withscores', '++limit'))
         offset = offset or 0
         count = -1 if count is None else count
@@ -271,8 +294,8 @@ class SortedSetCommandsMixin:
 
     @command((Key(ZSet), StringTest, StringTest))
     def zremrangebylex(self, key, _min, _max):
-        items = key.value.irange_lex(_min.value, _max.value,
-                                     inclusive=(not _min.exclusive, not _max.exclusive))
+        items = key.value.irange_lex(
+            _min.value, _max.value, inclusive=(not _min.exclusive, not _max.exclusive))
         return self.zrem(key, *items)
 
     @command((Key(ZSet), ScoreTest, ScoreTest))
@@ -315,7 +338,7 @@ class SortedSetCommandsMixin:
         else:
             raise SimpleError(msgs.WRONGTYPE_MSG)
 
-    def _zunioninter(self, func, dest, numkeys, *args):
+    def _zunioninterdiff(self, func, dest, numkeys, *args):
         if numkeys < 1:
             raise SimpleError(msgs.ZUNIONSTORE_KEYS_MSG.format(func.lower()))
         if numkeys > len(args):
@@ -346,11 +369,9 @@ class SortedSetCommandsMixin:
             sets.append(self._get_zset(item.value))
 
         out_members = set(sets[0])
+        method = SORTED_SET_METHODS[func]
         for s in sets[1:]:
-            if func == 'ZUNIONSTORE':
-                out_members |= set(s)
-            else:
-                out_members.intersection_update(s)
+            out_members = method(out_members, set(s))
 
         # We first build a regular dict and turn it into a ZSet. The
         # reason is subtle: a ZSet won't update a score from -0 to +0
@@ -364,7 +385,7 @@ class SortedSetCommandsMixin:
                 score *= w
                 # Redis only does this step for ZUNIONSTORE. See
                 # https://github.com/antirez/redis/issues/3954.
-                if func == 'ZUNIONSTORE' and math.isnan(score):
+                if func in {'ZUNIONSTORE', 'ZUNION'} and math.isnan(score):
                     score = 0.0
                 if member not in out_members:
                     continue
@@ -388,16 +409,67 @@ class SortedSetCommandsMixin:
         for member, score in out.items():
             out_zset[member] = score
 
+        if dest is None:
+            return out_zset
+
         dest.value = out_zset
         return len(out_zset)
 
     @command((Key(), Int, bytes), (bytes,))
     def zunionstore(self, dest, numkeys, *args):
-        return self._zunioninter('ZUNIONSTORE', dest, numkeys, *args)
+        return self._zunioninterdiff('ZUNIONSTORE', dest, numkeys, *args)
 
     @command((Key(), Int, bytes), (bytes,))
     def zinterstore(self, dest, numkeys, *args):
-        return self._zunioninter('ZINTERSTORE', dest, numkeys, *args)
+        return self._zunioninterdiff('ZINTERSTORE', dest, numkeys, *args)
+
+    @command((Key(), Int, bytes), (bytes,))
+    def zdiffstore(self, dest, numkeys, *args):
+        return self._zunioninterdiff('ZDIFFSTORE', dest, numkeys, *args)
+
+    @command((Int, bytes,), (bytes,))
+    def zdiff(self, numkeys, *args):
+        withscores = casematch(b'withscores', args[-1])
+        sets = args[:-1] if withscores else args
+        res = self._zunioninterdiff('ZDIFF', None, numkeys, *sets)
+
+        if withscores:
+            res = [item for t in res for item in (t, Float.encode(res[t], False))]
+        else:
+            res = [t for t in res]
+        return res
+
+    @command((Int, bytes,), (bytes,))
+    def zunion(self, numkeys, *args):
+        withscores = casematch(b'withscores', args[-1])
+        sets = args[:-1] if withscores else args
+        res = self._zunioninterdiff('ZUNION', None, numkeys, *sets)
+
+        if withscores:
+            res = [item for t in res for item in (t, Float.encode(res[t], False))]
+        else:
+            res = [t for t in res]
+        return res
+
+    @command((Int, bytes,), (bytes,))
+    def zinter(self, numkeys, *args):
+        withscores = casematch(b'withscores', args[-1])
+        sets = args[:-1] if withscores else args
+        res = self._zunioninterdiff('ZINTER', None, numkeys, *sets)
+
+        if withscores:
+            res = [item for t in res for item in (t, Float.encode(res[t], False))]
+        else:
+            res = [t for t in res]
+        return res
+
+    @command(name="ZINTERCARD", fixed=(Int, bytes,), repeat=(bytes,))
+    def zintercard(self, numkeys, *args):
+        (limit,), left_args = extract_args(
+            args, ('+limit',), error_on_unexpected=False, left_from_first_unexpected=False)
+        limit = limit if limit != 0 else sys.maxsize
+        res = self._zunioninterdiff('ZINTER', None, numkeys, *left_args)
+        return min(limit, len(res))
 
     @command(name="ZMSCORE", fixed=(Key(ZSet), bytes), repeat=(bytes,))
     def zmscore(self, key: CommandItem, *members: Union[str, bytes]) -> list[Optional[float]]:
@@ -413,5 +485,30 @@ class SortedSetCommandsMixin:
         )
         return list(scores)
 
+    @command(name="ZRANDMEMBER", fixed=(Key(ZSet),), repeat=(bytes,))
+    def zrandmember(self, key: CommandItem, *args) -> list[Optional[float]]:
+        count, withscores = 1, None
+        if len(args) > 0:
+            count = Int.decode(args[0])
+        if len(args) > 1:
+            if casematch(b'withscores', args[1]):
+                withscores = True
+            else:
+                raise SimpleError(msgs.SYNTAX_ERROR_MSG)
+        zset = key.value
+        if zset is None:
+            return None if len(args) == 0 else []
+        if count < 0:  # Allow repetitions
+            res = random.choices(sorted(key.value.items()), k=-count)
+        else:  # Unique values from hash
+            count = min(count, len(key.value))
+            res = random.sample(sorted(key.value.items()), count)
+
+        if withscores:
+            res = [item for t in res for item in t]
+        else:
+            res = [t[0] for t in res]
+        return res
+
     def _encodefloat(self, value, humanfriendly):
         raise NotImplementedError  # Implemented in BaseFakeSocket
